<?php

use EventPortal\Domain\Approval\Models\Approval;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Event\Models\EventDelegate;
use EventPortal\Domain\EventDelegate\Actions\MarkDelegateAsInvited;
use EventPortal\Domain\Util\Notification\Models\EventNotification;

return [
    'event' => [
        // class of your domain object
        'class' => Event::class,

        // name of the graph (default is "default")
        'graph' => 'event',

        // property of your object holding the actual state (default is "state")
        'property_path' => 'status',

        // list of all possible states
        'states' => [
            [
                'name' => 'draft',
                'metadata' => ['title' => 'Draft', 'viewable' => false],
            ],
            [
                'name' => 'published',
                'metadata' => ['title' => 'Published', 'viewable' => true],
            ],
            [
                'name' => 'post',
                'metadata' => ['title' => 'Post', 'viewable' => true],
            ],
            [
                'name' => 'cancelled',
                'metadata' => ['title' => 'Cancelled', 'viewable' => true],
            ],
            [
                'name' => 'archived',
                'metadata' => ['title' => 'Archived', 'viewable' => false],
            ],
        ],

        // list of all possible transitions
        'transitions' => [
            'publish' => [
                'from' => ['draft'],
                'to' => 'published',
                'metadata' => ['title' => 'Publish'],
            ],
            'complete' => [
                'from' => ['published'],
                'to' => 'post',
                'metadata' => ['title' => 'Complete'],
            ],
            'cancel' => [
                'from' => ['published'],
                'to' => 'cancelled',
                'metadata' => ['title' => 'Cancel'],
            ],
            'archive' => [
                'from' => ['draft', 'post', 'cancelled'],
                'to' => 'archived',
                'metadata' => ['title' => 'Archive'],
            ],
            'redraft' => [
                'from' => ['archived'],
                'to' => 'draft',
                'metadata' => ['title' => 'Restore (to Draft)'],
            ],
            'repost' => [
                'from' => ['archived'],
                'to' => 'post',
                'metadata' => ['title' => 'Restore (to Post)'],
            ],
        ],

        // list of all callbacks
        'callbacks' => [
            // will be called when testing a transition
            'guard' => [
                //                'guard_on_submitting' => [
                //                    // call the callback on a specific transition
                //                    'on' => 'submit_changes',
                //                    // will call the method of this class
                //                    'do' => ['MyClass', 'handle'],
                //                    // arguments for the callback
                //                    'args' => ['object'],
                //                ],
                //                'guard_on_approving' => [
                //                    // call the callback on a specific transition
                //                    'on' => 'approve',
                //                    // will check the ability on the gate or the class policy
                //                    'can' => 'approve',
                //                ],
            ],

            // will be called before applying a transition
            'before' => [],

            // will be called after applying a transition
            'after' => [
                'history' => [
                    'do' => 'StateHistoryManager@storeHistory',
                ],
            ],
        ],
    ],

    'eventDelegate' => [
        // class of your domain object
        'class' => EventDelegate::class,

        // name of the graph (default is "default")
        'graph' => 'eventDelegate',

        // property of your object holding the actual state (default is "state")
        'property_path' => 'status',

        // list of all possible states
        'states' => [
            [
                'name' => 'candidate',
                'metadata' => [
                    'title' => 'Candidate',
                    'viewable' => false,
                ],
            ],
            [
                'name' => 'invited',
                'metadata' => [
                    'title' => 'Invited',
                    'viewable' => true,
                ],
            ],
            [
                'name' => 'registering',
                'metadata' => [
                    'title' => 'Registering',
                    'viewable' => true,
                ],
            ],
            [
                'name' => 'registered',
                'metadata' => [
                    'title' => 'Registered',
                    'viewable' => true,
                ],
            ],
            [
                'name' => 'declining',
                'metadata' => [
                    'title' => 'Declining',
                    'viewable' => true,
                ],
            ],
            [
                'name' => 'declined',
                'metadata' => [
                    'title' => 'Declined',
                    'viewable' => true,
                ],
            ],
            [
                'name' => 'attended',
                'metadata' => [
                    'title' => 'Attended',
                    'viewable' => true,
                ],
            ],
            [
                'name' => 'cancelled',
                'metadata' => [
                    'title' => 'Cancelled',
                    'viewable' => true,
                ],
            ],
            [
                'name' => 'no_show',
                'metadata' => [
                    'title' => 'No Show',
                    'viewable' => true,
                ],
            ],
        ],

        // list of all possible transitions
        'transitions' => [
            'invite' => [
                'from' => ['candidate'],
                'to' => 'invited',
                'metadata' => ['title' => ' To Invited'],
            ],
            'registering' => [
                'from' => ['invited'],
                'to' => 'registering',
                'metadata' => ['title' => 'To Registering'],
            ],
            'registered' => [
                'from' => ['invited', 'registering'],
                'to' => 'registered',
                'metadata' => ['title' => 'To Registered'],
            ],
            'declining' => [
                'from' => ['invited', 'registering'],
                'to' => 'declined',
                'metadata' => ['title' => 'To Declining'],
            ],
            'declined' => [
                'from' => ['invited', 'registering'],
                'to' => 'declined',
                'metadata' => ['title' => 'To Declined'],
            ],
            'attended' => [
                'from' => ['registered'],
                'to' => 'attended',
                'metadata' => ['title' => 'To Attended'],
            ],
            'cancelled' => [
                'from' => ['invited', 'registering', 'registered', 'declined'],
                'to' => 'cancelled',
                'metadata' => ['title' => 'To Cancelled'],
            ],
            'no_show' => [
                'from' => ['invited', 'registering', 'registered'],
                'to' => 'no_show',
                'metadata' => ['title' => 'To No Show'],
            ],
        ],

        // list of all callbacks
        'callbacks' => [
            // will be called when testing a transition
            'guard' => [
                //                'guard_on_submitting' => [
                //                    // call the callback on a specific transition
                //                    'on' => 'submit_changes',
                //                    // will call the method of this class
                //                    'do' => ['MyClass', 'handle'],
                //                    // arguments for the callback
                //                    'args' => ['object'],
                //                ],
                //                'guard_on_approving' => [
                //                    // call the callback on a specific transition
                //                    'on' => 'approve',
                //                    // will check the ability on the gate or the class policy
                //                    'can' => 'approve',
                //                ],
            ],

            // will be called before applying a transition
            'before' => [],

            // will be called after applying a transition
            'after' => [
                'history' => [
                    'do' => 'StateHistoryManager@storeHistory',
                ],
            ],
        ],
    ],





    'eventNotification' => [
        // class of your domain object
        'class' => EventNotification::class,

        // name of the graph (default is "default")
        'graph' => 'eventNotification',

        // property of your object holding the actual state (default is "state")
        'property_path' => 'status',

        // list of all possible states
        'states' => [
            [
                'name' => 'queued',
                'metadata' => ['title' => 'Sending...'],
            ],
            [
                'name' => 'sent',
                'metadata' => ['title' => 'Sent'],
            ],
            [
                'name' => 'delivered',
                'metadata' => ['title' => 'Delivered'],
            ],
            [
                'name' => 'bounced',
                'metadata' => ['title' => 'Bounced'],
            ],
            [
                'name' => 'rejected',
                'metadata' => ['title' => 'Rejected'],
            ],
        ],

        // list of all possible transitions
        'transitions' => [
            'sent' => [
                'from' => ['queued'],
                'to' => 'sent',
            ],
            'delivered' => [
                'from' => ['queued'],
                'to' => 'delivered',
            ],
            'bounced' => [
                'from' => ['queued'],
                'to' => 'bounced',
            ],
            'rejected' => [
                'from' => ['queued'],
                'to' => 'rejected',
            ],
        ],

        // list of all callbacks
        'callbacks' => [
            // will be called when testing a transition
            'guard' => [],

            // will be called before applying a transition
            'before' => [],

            // will be called after applying a transition
            'after' => [
                'mark_delegate_invited' => [
                    'on' => 'sent',
                    'do' => [
                        MarkDelegateAsInvited::class,
                        'execute',
                    ],
                ],
            ],
        ],
    ],

    'novoVisionMiff' => [
        // class of your domain object
        'class' => Approval::class,

        // name of the graph (default is "default")
        'graph' => 'novoVisionMiff',

        // property of your object holding the actual state (default is "state")
        'property_path' => 'status',

        // list of all possible states
        'states' => [
            [
                'name' => 'awaiting-approval',
                'metadata' => [
                    'alert' => 'warning',
                    'description' => 'Your event is awaiting approval.',
                    'title' => 'Awaiting',
                    'viewable' => true,
                ],
            ],
            [
                'name' => 'requires-resubmission',
                'metadata' => [
                    'alert' => 'warning',
                    'description' => 'Your event needs resubmitting for approval due to update that you have made to 
                    your event.',
                    'title' => 'Requires Resubmission',
                    'viewable' => true,
                ],
            ],
            [
                'name' => 'line-manager-approved',
                'metadata' => [
                    'alert' => 'warning',
                    'description' => 'Your event is awaiting approval from the compliance manager.',
                    'title' => 'Line Manager Approved',
                    'viewable' => true,
                ],
            ],
            [
                'name' => 'approved',
                'metadata' => [
                    'alert' => 'success',
                    'description' => 'Your event has been approved! You can now proceed with :event.',
                    'title' => 'Approved',
                    'viewable' => true,
                ],
            ],
            [
                'name' => 'declined',
                'metadata' => [
                    'alert' => 'error',
                    'description' => 'Your event has been declined. Read the notes provided to see where your event 
                    needs improvement.',
                    'title' => 'Declined',
                    'viewable' => true,
                ],
            ],
        ],

        // list of all possible transitions
        'transitions' => [
            'requires-resubmission' => [
                'from' => ['awaiting-approval', 'declined',  'line-manager-approved', 'approved'],
                'to' => 'requires-resubmission',
                'metadata' => ['title' => 'Requires Resubmission'],
            ],
            'line-manager-approved' => [
                'from' => ['awaiting-approval', 'declined'],
                'to' => 'line-manager-approved',
                'metadata' => ['title' => 'Line Manager Approved'],
            ],
            'approved' => [
                'from' => ['awaiting-approval', 'line-manager-approved', 'declined'],
                'to' => 'approved',
                'metadata' => ['title' => 'Approved'],
            ],
            'declined' => [
                'from' => ['awaiting-approval', 'line-manager-approved'],
                'to' => 'declined',
                'metadata' => ['title' => 'Declined'],
            ],
        ],

        // list of all callbacks
        'callbacks' => [
            // will be called when testing a transition
            'guard' => [
            ],

            // will be called before applying a transition
            'before' => [],

            // will be called after applying a transition
            'after' => [
                'history' => [
                    'do' => 'StateHistoryManager@storeHistory',
                ],
            ],
        ],
    ],
];
