<?php

namespace EventPortal\Tests\Feature\Delegate\Event;

use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class EventStatusTest extends TestCase
{
    use RefreshDatabase;

    /** @test */
    public function cannot_view_event_if_event_status_draft(): void
    {
        [$event, $delegate] = $this->setupEvent('draft');

        $this
            ->actingAsDelegate($delegate)
            ->get(route('delegate.landing', ['event' => $event->slug]))
            ->assertNotFound();
    }

    /** @test */
    public function cannot_view_event_if_event_status_archived(): void
    {
        [$event, $delegate] = $this->setupEvent('archived');

        $this
            ->actingAsDelegate($delegate)
            ->get(route('delegate.landing', ['event' => $event->slug]))
            ->assertNotFound();
    }

    /** @test */
    public function can_view_event_if_status_is_published(): void
    {
        [$event, $delegate] = $this->setupEvent('published');

        $this
            ->actingAsDelegate($delegate)
            ->get(route('delegate.landing', ['event' => $event->slug]))
            ->assertOk();
    }

    /** @test */
    public function can_view_event_if_status_is_post(): void
    {
        [$event, $delegate] = $this->setupEvent('post');

        $this
            ->actingAsDelegate($delegate)
            ->get(route('delegate.landing', ['event' => $event->slug]))
            ->assertOk();
    }

    /** @test */
    public function can_view_event_if_status_is_cancelled(): void
    {
        [$event, $delegate] = $this->setupEvent('cancelled');

        $this
            ->actingAsDelegate($delegate)
            ->get(route('delegate.landing', ['event' => $event->slug]))
            ->assertRedirect(route('event.cancelled', ['event' => $event->slug]));
    }

    private function setupEvent(string $eventStatus = 'published', string $delegateStatus = 'invited'): array
    {
        $delegate = factory(Delegate::class)->state('snapshot')->create();

        $event = factory(Event::class)->state('snapshot')->create(['status' => $eventStatus]);

        $event->delegates()->attach($delegate, ['status' => $delegateStatus, 'pathway_id' => 1]);

        return [$event, $delegate];
    }
}
