<?php

namespace EventPortal\Tests\Unit\Agenda\Actions;

use EventPortal\Domain\Agenda\Actions\DeleteSession;
use EventPortal\Domain\Agenda\Models\Session;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Event\Models\EventSpeaker;
use EventPortal\Domain\Speaker\Models\Speaker;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class DeleteSessionTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_delete_session()
    {
        $session = factory(Session::class)->create();

        (new DeleteSession)->execute($session);

        $this->assertDatabaseMissing('sessions', [
            'id' => $session->id,
        ]);
    }

    /** @test **/
    public function detaches_speakers_on_delete()
    {
        $event = factory(Event::class)->create();

        $eventSpeakerA = factory(EventSpeaker::class)->create(['event_id' => $event->id]);
        $eventSpeakerB = factory(EventSpeaker::class)->create(['event_id' => $event->id]);

        $session = factory(Session::class)->create();

        $session->eventSpeakers()->attach([$eventSpeakerA->id, $eventSpeakerB->id]);

        $this->assertDatabaseCount('event_speaker_session', 2);
        $this->assertDatabaseCount('speakers', 2);

        (new DeleteSession)->execute($session);

        $this->assertDatabaseCount('event_speaker_session', 0);
        $this->assertDatabaseCount('speakers', 2);

        $this->assertDatabaseMissing('sessions', [
            'id' => $session->id,
        ]);
    }
}
